function [ net, info ] = MatConvNet_ReTrainDAG( netToUse, rootFolder, new)
    if(nargin==0)
        rootFolder = '/home/CNN_files';

        % Definisco le classi su cui addestare il classficatore
        % Mettere prima la classe "positiva"
        %categories = {'oro', 'none'};

        % googlenet, resnet_152
        netToUse = 'resnet_152'; 

        new = 3;
    end


    switch netToUse
        case 'googlenet'
            % Definisco il nome del modello
            netName = 'imagenet-googlenet-dag.mat';

        case 'resnet_152'
            % Definisco il nome del modello
            netName = 'imagenet-resnet-152-dag.mat';

        otherwise
            error('nome della rete sconosciuto');
    end

    %% CARICAMENTO CNN
    % ATTENZIONE: è necessario avviare il setup prima di eseguire questa
    % sezione (run <matconvnet_root>/matlab/vl_setupnn)
    % Carica il modello ConvNet...
    net = load(netName);
    net = dagnn.DagNN.loadobj(net) ;
    % ...imposto il modello in test mode...
    %net.mode = 'test' ;


    %% SOSTITUZIONE DEGLI ULTIMI LAYER
    switch netToUse
        case 'googlenet'
            %rimuovo:
            %   - cls3_fc perchè il layer che definisce il numero di uscite 
            %   - softmax perchè il layer di classificazione
            net.removeLayer({'cls3_fc', 'softmax'});
            %rimuovo:
            %   - questi layer sono responsabili della classificazione nei
            %   livelli precedenti (conv->fc->fc->softmax) perchè non avendo le
            %   label in questi layer, le derivate non vengono calcolate        
            net.removeLayer({'cls1_pool','cls1_reduction','relu_cls1_reduction','cls1_fc1','relu_cls1_fc1','cls1_fc2'});
            net.removeLayer({'cls2_pool','cls2_reduction','relu_cls2_reduction','cls2_fc1','relu_cls2_fc1','cls2_fc2'});

            %aggiungo il layer fc come layer conv (perchè non esiste il layer FC
            % https://github.com/vlfeat/matconvnet/issues/491
            % http://cs231n.github.io/convolutional-networks [Converting FC layers to CONV layers]
            net.addLayer('cls3_fcNEW', dagnn.Conv('size', [1 1 1024 new], 'hasBias', true, 'stride', [1, 1], 'pad', [0 0 0 0]), {'cls3_pool'}, {'cls3_fcNEW'}, {'newparams1',  'newparams2'});
            net.addLayer('softmaxNEW', dagnn.SoftMax(), {'cls3_fcNEW'}, {'probNEW'}, {});

            % aggiungo dei layer per definire l'errore di classificazione
            net.addLayer('objective', dagnn.Loss('loss', 'log'),        {'probNEW','label'}, {'objective'}, {});
            net.addLayer('error',     dagnn.Loss('loss', 'classerror'), {'probNEW','label'}, {'error'},     {});

            % inizializzo i nuovi parametri
            net.params(115).value = 1/1000*rand([1,1,1024,new], 'single');
            net.params(116).value = 1/1000*rand([new,1], 'single');
        case 'resnet_152'
            %rimuovo:
            %   - fc1000 perchè il layer che definisce il numero di uscite 
            %   - prob perchè il layer di classificazione
            net.removeLayer({'fc1000', 'prob'});

            %aggiungo il layer fc come layer conv
            % https://github.com/vlfeat/matconvnet/issues/491
            % http://cs231n.github.io/convolutional-networks [Converting FC layers to CONV layers]
            net.addLayer('fc1000NEW',  dagnn.Conv('size', [1 1 2048 new], 'hasBias', true, 'stride', [1, 1], 'pad', [0 0 0 0]), {'pool5'}, {'fc1000NEW'}, {'newparams1',  'newparams2'});
            net.addLayer('softmaxNEW', dagnn.SoftMax(), {'fc1000NEW'}, {'probNEW'}, {});

            % aggiungo dei layer per definire l'errore di classificazione
            net.addLayer('objective', dagnn.Loss('loss', 'log'),        {'probNEW','label'}, {'objective'}, {});
            net.addLayer('error',     dagnn.Loss('loss', 'classerror'), {'probNEW','label'}, {'error'},     {}) ;

            % inizializzo i nuovi parametri
            net.params(621).value = 1/1000*rand([1,1,2048,new], 'single');
            net.params(622).value = 1/1000*rand([new,1], 'single');
        otherwise
            error('nome della rete sconosciuto');
    end
    
    %% CARICO IMDS
    imdb = mioImageFolderToImdb(rootFolder, 'imdb_name');
    
    %% ADDESTRO MODELLO
    gpus = [];% [], 1
    bopts = struct('numGpus', numel(gpus)) ; % serve per modificare il getBatch nel caso GPU
    [net, info] = cnn_train_dag(net, imdb, @(x,y) getbatchDAG(bopts, x,y), 'batchSize', 64, 'gpus', gpus, 'continue', false, 'numEpochs', 50);
end





