function [ pos ] = findSpotGUI( im, index_Selected )
%Implementazione del 2D top-hat 
% INPUT:  im:    immagine
%
% OUTPUT: pos: matrice Nx6 (con N num di centroidi). 
%                Altre colonne - Cx
%                                Cy
%                                raggio_cluster
%                                intensità
%                                somma quadrati intracluster
%                                tipo (0 = negativo; 1 = positivo)


%disp('Implementazione del 2D top-hat con H adattivo...');

% standardizzazione dei risultati (riproducibilità)
rng('default');
rng(1);

im(:,1:2) = 0;
im(:,end-1:end) = 0;

% utilizza newTH come funzione per l'implementazione di 2D tophat
out = nlfilter2(im, [9 9], @newTH);

stats = regionprops(logical(out), im, 'Centroid');
%stats = stats([stats.Area]>1);
centroids = cat(1, stats.Centroid);

clear out;

%% VISUALIZZAZIONE (Dipende del numero di aree sospette)
if(size(centroids, 1)>5)
    %% se ho pi� di 5 aree sospette
    %% valutazione del miglior numero di cluster per k means
    %  solo se il numero di aree (size(centroids, 1)) � >5
    clust = zeros(size(centroids,1),5);

    for i=1:5
        clust(:,i) = kmeans(centroids, i,'Distance','cityblock',...
        'Replicates',5);    
    end

    eva = evalclusters(centroids,clust,'CalinskiHarabasz');
    %disp(strcat('Trovati N=', num2str(eva.OptimalK), ' cluster'));
    

    %% esecuzione del miglior k means
    [idx,C, sumd, D] = kmeans(centroids, eva.OptimalK,'Distance','cityblock',...
        'Replicates',5);    

    %% creo una mat Nx6 che descrive i vari cluster con:
    %    - x del centroide
    %    - y del centroide 
    %    - raggio del cluster
    %    - numero di elementi
    %    - intensit�
    %    - sumd
    pos = zeros(eva.OptimalK, 6);
    for i=1:eva.OptimalK
        pos(i, :) = [C(i,1) C(i,2) max(10, max(D(idx==i,i))) sum(idx==i)...
            0 0];     
    end

    pos(:,5) = pos(:,4)./(pi*pos(:, 3).^2).*10000;%intensità
    pos(:,6) = sumd;%somma dei quadrati delle distanze intracluster
    
else
    if(size(centroids, 1)==0)
       % disp(strcat('Trovati N=0 cluster'));
        % se non � stato trovato alcun pixel sospetto mostra solo
        % l'immagine
        pos = zeros(1,6);
        idx = [];
    else
        %disp(strcat('Trovati N=1 cluster'));
        %altrimenti usare kmeans con un solo centro
        [idx,C, sumd, D] = kmeans(centroids, 1);      
        pos = zeros(1, 4);
        pos(1, :) = [C(1,1) C(1,2) max(10, max(D(idx==1,1))) sum(idx==1)];        
        pos(:,end+1) = pos(:,4)./(pi*pos(:, 3).^2).*10000;%intensità
        pos(:,end+1) = sumd;%somma dei quadrati delle distanze intracluster
    end
    
end
pos = array2table(pos,...
    'VariableNames',{'Cx','Cy','RaggioCluster', 'NumIstanze','Intensita', ...
    'SommaQuadrati'});
pos = table2struct(pos);
for i=1:size(pos,1)
    pos(i).MicroCentroids = centroids(idx==i,:);
    pos(i).Slice = index_Selected; 
    pos(i).Tipo = false;
end
end