function [ predictedLabel ] = testClassifier( classifier, dataLayer, featuresLayer, net, image )
% Testa una rete deep (net) e un classificatore (classifier) su una
% immagine o una serie di immagini (image). 
% FASI:
% 1) adatto l'immagine 
% 2) sottopongo l'immagine/le immagini alla rete ed straggo le attivazioni
% 3) eseguo la predizione sul classificatore
% 
% RESTITUISCE:
% 1x1 categorical se sottometto una immagine singola
% Nx1 categorical se sottometto N immagini 3D (RGB) concatenate lungo la 4a dimensione
% 
% ESEMPI:
% singola immagine:
%    net = load('imagenet-vgg-s.mat') ;
%    net = vl_simplenn_tidy(net) ;
%    net = dagnn.DagNN.fromSimpleNN(net);
%    classifier = load('classificatore.mat');
%    image = imread('urlimmagine.bmp');
%    c = testClassifier(classifier, 'x0', 'x15', net, image);
%
% pi immagini (c diventa un 2x1 categorical):
%    image1 = imread('urlimmagine1.bmp');
%    image1 = cat(3, image1,image1,image1);
%    image2 = imread('urlimmagine2.bmp');
%    image2 = cat(3, image2,image2,image2);
%    image4D = cat(4, image1, image2);
%    c = testClassifier(classifier, 'x0', 'x15', net, image4D);
%


infoImage = whos('image');
if numel(infoImage.size)==2
    image = cat(3,image, image, image);
end
if strcmp(infoImage.class, 'uint8')
    image = single(image);
end

image = imresize(image, net.meta.normalization.imageSize(1:2));

net.eval({dataLayer, image});
net.vars(net.getVarIndex(featuresLayer)).precious = 1;
scores = net.vars(net.getVarIndex(featuresLayer)).value ;
scores = double(squeeze(gather(scores)));

predictedLabel = classifier.predict(scores');

end

